SocksConnectException class

Inheritance

Constructors

SocksConnectException(SocksConnectError code, String message, {int? replyCode})
const

Properties

address → InternetAddress?
The address of the socket giving rise to the exception.
finalinherited
code → SocksConnectError
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Description of the error.
finalinherited
osError → OSError?
The underlying OS error.
finalinherited
port → int?
The port of the socket giving rise to the exception.
finalinherited
reply → SocksReplyCode?
no setter
replyCode → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited