SocksConnection class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
start(
{required InternetAddress proxyHost, required int proxyPort, required String targetHost, required int targetPort, String? tlsHost, SecurityContext? securityContext, SocksCredentials? credentials, List< String> ? supportedProtocols, Duration timeout = const Duration(seconds: 30)}) → ConnectionTask<Socket>