SocksReplyCode enum

SOCKS5 reply codes as defined in RFC 1928 section 6.

Inheritance
Available extensions

Values

generalFailure → const SocksReplyCode
const SocksReplyCode(0x01, 'General SOCKS server failure')
connectionNotAllowed → const SocksReplyCode
const SocksReplyCode(0x02, 'Connection not allowed by ruleset')
networkUnreachable → const SocksReplyCode
const SocksReplyCode(0x03, 'Network unreachable')
hostUnreachable → const SocksReplyCode
const SocksReplyCode(0x04, 'Host unreachable')
connectionRefused → const SocksReplyCode
const SocksReplyCode(0x05, 'Connection refused')
ttlExpired → const SocksReplyCode
const SocksReplyCode(0x06, 'TTL expired')
commandNotSupported → const SocksReplyCode
const SocksReplyCode(0x07, 'Command not supported')
addressTypeNotSupported → const SocksReplyCode
const SocksReplyCode(0x08, 'Address type not supported')

Properties

byte → int
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromByte(int byte) → SocksReplyCode?
Null for unknown codes and for success (0x00).

Constants

values → const List<SocksReplyCode>
A constant List of the values in this enum, in order of their declaration.